@@ -104,7 +104,8 @@ class Base(Controller):
             raise NotImplementedError('As action, chose one of {update, show}')
 
     @ex(
-        help="GCP VM Instances helper commands.",
+        help="GCP VM Instances helper commands."
+        "These are currently in alpha and some may not work",
         arguments=[
             (['action'],{
                     "help" : "To show one of {ls, scp}.",
@@ -231,45 +232,6 @@ class Base(Controller):
         write_sftp(name=server_name, ip=ip, port=port, user=user,
                     remote=remote, key_path=identity)
 
-
-    @ex(
-        help="Display all available Fluidstack nodes.",
-        arguments=[
-            (['action'],{
-                "help" : "To show one of {avail, ls, start, stop}.",
-                "action" : "store"
-            }),
-            (['-stats'],{
-            "help" : "One of {all, gpu} to show either all (df) or gpu (json)",
-            "action": "store"
-            }),
-            (['-n_gpu'],{
-                "help" : "# of gpus required to be on the machine",
-                "action" : "store"
-            }),
-            (['-id'],{
-                "help" : "ID of the container to work with",
-                "action" : "store"
-            })
-        ]
-    )
-    def fls(self):
-        from ..ext.fluidstack import avail_fl_nodes, show_running, \
-            stop_container, start_container
-
-        args = self.app.pargs
-        if args.action=='avail':
-            avail_fl_nodes(args.stats, args.n_gpu)
-        elif args.action=='ls':
-            show_running()
-        elif args.action=='stop':
-            stop_container(args.id)
-        elif args.action=='start':
-            start_container(args.id)
-
-        else:
-            raise NotImplementedError('Set the first parg to one of {avail, ls, start, stop}')
-
     @ex(
         help="Ops with Codex AI from OpenAI.",
         arguments=[
